weaviate.collections package
============================

.. automodule:: weaviate.collections
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   weaviate.collections.aggregations
   weaviate.collections.batch
   weaviate.collections.classes
   weaviate.collections.grpc
   weaviate.collections.queries

Submodules
----------

weaviate.collections.aggregate module
-------------------------------------

.. automodule:: weaviate.collections.aggregate
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.collection module
--------------------------------------

.. automodule:: weaviate.collections.collection
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.collections module
---------------------------------------

.. automodule:: weaviate.collections.collections
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.config module
----------------------------------

.. automodule:: weaviate.collections.config
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.data module
--------------------------------

.. automodule:: weaviate.collections.data
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.filters module
-----------------------------------

.. automodule:: weaviate.collections.filters
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.iterator module
------------------------------------

.. automodule:: weaviate.collections.iterator
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.query module
---------------------------------

.. automodule:: weaviate.collections.query
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.tenants module
-----------------------------------

.. automodule:: weaviate.collections.tenants
   :members:
   :undoc-members:
   :show-inheritance:
